summaryrefslogtreecommitdiff
path: root/libs/ardour/ardour
diff options
context:
space:
mode:
Diffstat (limited to 'libs/ardour/ardour')
-rw-r--r--libs/ardour/ardour/automation_event.h2
-rw-r--r--libs/ardour/ardour/canvas_vars.h2
-rw-r--r--libs/ardour/ardour/io_processor.h (renamed from libs/ardour/ardour/redirect.h)16
-rw-r--r--libs/ardour/ardour/meter.h6
-rw-r--r--libs/ardour/ardour/plugin_insert.h4
-rw-r--r--libs/ardour/ardour/port_insert.h6
-rw-r--r--libs/ardour/ardour/processor.h (renamed from libs/ardour/ardour/insert.h)16
-rw-r--r--libs/ardour/ardour/route.h114
-rw-r--r--libs/ardour/ardour/send.h4
-rw-r--r--libs/ardour/ardour/session.h8
-rw-r--r--libs/ardour/ardour/track.h29
11 files changed, 101 insertions, 106 deletions
diff --git a/libs/ardour/ardour/automation_event.h b/libs/ardour/ardour/automation_event.h
index af1a3cb704..f76b12f41d 100644
--- a/libs/ardour/ardour/automation_event.h
+++ b/libs/ardour/ardour/automation_event.h
@@ -93,7 +93,7 @@ class AutomationList : public PBD::StatefulDestructible
void reposition_for_rt_add (double when);
void rt_add (double when, double value);
void add (double when, double value);
- /* this should be private but old-school automation loading needs it in IO/Redirect */
+ /* this should be private but old-school automation loading needs it in IO/IOProcessor */
void fast_simple_add (double when, double value);
void reset_range (double start, double end);
diff --git a/libs/ardour/ardour/canvas_vars.h b/libs/ardour/ardour/canvas_vars.h
index 35af35e2ac..2d9e7ae03c 100644
--- a/libs/ardour/ardour/canvas_vars.h
+++ b/libs/ardour/ardour/canvas_vars.h
@@ -9,7 +9,7 @@ CANVAS_VARIABLE(canvasvar_MidiBusBase, "midi bus base")
CANVAS_VARIABLE(canvasvar_TimeStretchFill, "time-stretch-fill")
CANVAS_VARIABLE(canvasvar_TimeStretchOutline, "time-stretch-outline")
CANVAS_VARIABLE(canvasvar_AutomationLine, "automation line")
-CANVAS_VARIABLE(canvasvar_RedirectAutomationLine, "redirect automation line")
+CANVAS_VARIABLE(canvasvar_ProcessorAutomationLine, "processor automation line")
CANVAS_VARIABLE(canvasvar_ControlPointFill, "control point fill")
CANVAS_VARIABLE(canvasvar_ControlPointOutline, "control point outline")
CANVAS_VARIABLE(canvasvar_EnteredControlPointOutline, "entered control point outline")
diff --git a/libs/ardour/ardour/meter.h b/libs/ardour/ardour/meter.h
index 7e0bf8ac53..c78cdebfb0 100644
--- a/libs/ardour/ardour/meter.h
+++ b/libs/ardour/ardour/meter.h
@@ -21,7 +21,7 @@
#include <vector>
#include <ardour/types.h>
-#include <ardour/insert.h>
+#include <ardour/processor.h>
#include <pbd/fastlog.h>
namespace ARDOUR {
@@ -33,9 +33,9 @@ class Session;
/** Meters peaks on the input and stores them for access.
*/
-class PeakMeter : public Insert {
+class PeakMeter : public Processor {
public:
- PeakMeter(Session& s) : Insert(s, "meter", PreFader) {}
+ PeakMeter(Session& s) : Processor(s, "meter", PreFader) {}
void reset ();
void reset_max ();
diff --git a/libs/ardour/ardour/plugin_insert.h b/libs/ardour/ardour/plugin_insert.h
index df0460af84..ea8f78b62f 100644
--- a/libs/ardour/ardour/plugin_insert.h
+++ b/libs/ardour/ardour/plugin_insert.h
@@ -27,7 +27,7 @@
#include <ardour/ardour.h>
#include <ardour/plugin_state.h>
#include <ardour/types.h>
-#include <ardour/insert.h>
+#include <ardour/processor.h>
#include <ardour/automation_event.h>
class XMLNode;
@@ -40,7 +40,7 @@ class Plugin;
/** Plugin inserts: send data through a plugin
*/
-class PluginInsert : public Insert
+class PluginInsert : public Processor
{
public:
PluginInsert (Session&, boost::shared_ptr<Plugin>, Placement);
diff --git a/libs/ardour/ardour/port_insert.h b/libs/ardour/ardour/port_insert.h
index 5d9cd583cb..1f366ae259 100644
--- a/libs/ardour/ardour/port_insert.h
+++ b/libs/ardour/ardour/port_insert.h
@@ -26,7 +26,7 @@
#include <sigc++/signal.h>
#include <ardour/ardour.h>
-#include <ardour/redirect.h>
+#include <ardour/io_processor.h>
#include <ardour/plugin_state.h>
#include <ardour/types.h>
@@ -37,10 +37,8 @@ namespace ARDOUR {
class Session;
/** Port inserts: send output to a Jack port, pick up input at a Jack port
- *
- * PortInsert IS-A Redirect IS-A Insert, IO
*/
-class PortInsert : public Redirect
+class PortInsert : public IOProcessor
{
public:
PortInsert (Session&, Placement);
diff --git a/libs/ardour/ardour/insert.h b/libs/ardour/ardour/processor.h
index 3fc9fbd1e4..7d126e8e0c 100644
--- a/libs/ardour/ardour/insert.h
+++ b/libs/ardour/ardour/processor.h
@@ -17,8 +17,8 @@
*/
-#ifndef __ardour_insert_h__
-#define __ardour_insert_h__
+#ifndef __ardour_processor_h__
+#define __ardour_processor_h__
#include <vector>
#include <string>
@@ -43,16 +43,16 @@ class Session;
/* A mixer strip element - plugin, send, meter, etc.
*/
-class Insert : public Automatable
+class Processor : public Automatable
{
public:
static const string state_node_name;
- Insert(Session&, const string& name, Placement p); // TODO: remove placement in favour of sort key
+ Processor(Session&, const string& name, Placement p); // TODO: remove placement in favour of sort key
- virtual ~Insert() { }
+ virtual ~Processor() { }
- static boost::shared_ptr<Insert> clone (boost::shared_ptr<const Insert>);
+ static boost::shared_ptr<Processor> clone (boost::shared_ptr<const Processor>);
uint32_t sort_key() const { return _sort_key; }
void set_sort_key (uint32_t key);
@@ -93,7 +93,7 @@ class Insert : public Automatable
void *get_gui () const { return _gui; }
void set_gui (void *p) { _gui = p; }
- static sigc::signal<void,Insert*> InsertCreated;
+ static sigc::signal<void,Processor*> ProcessorCreated;
sigc::signal<void> ActiveChanged;
sigc::signal<void> PlacementChanged;
@@ -110,4 +110,4 @@ protected:
} // namespace ARDOUR
-#endif /* __ardour_insert_h__ */
+#endif /* __ardour_processor_h__ */
diff --git a/libs/ardour/ardour/send.h b/libs/ardour/ardour/send.h
index dc509514e2..26d0351bb2 100644
--- a/libs/ardour/ardour/send.h
+++ b/libs/ardour/ardour/send.h
@@ -28,11 +28,11 @@
#include <ardour/ardour.h>
#include <ardour/audioengine.h>
#include <ardour/io.h>
-#include <ardour/redirect.h>
+#include <ardour/io_processor.h>
namespace ARDOUR {
-class Send : public Redirect
+class Send : public IOProcessor
{
public:
Send (Session&, Placement);
diff --git a/libs/ardour/ardour/session.h b/libs/ardour/ardour/session.h
index 9001196b60..3a4a21cb8a 100644
--- a/libs/ardour/ardour/session.h
+++ b/libs/ardour/ardour/session.h
@@ -87,9 +87,9 @@ class MidiDiskstream;
class AudioFileSource;
class MidiSource;
class Auditioner;
-class Insert;
+class Processor;
class Send;
-class Redirect;
+class IOProcessor;
class PortInsert;
class PluginInsert;
class Bundle;
@@ -1519,8 +1519,8 @@ class Session : public PBD::StatefulDestructible
uint32_t insert_cnt;
- void add_insert (Insert *);
- void remove_insert (Insert *);
+ void add_processor (Processor *);
+ void remove_processor (Processor *);
/* S/W RAID */
diff --git a/libs/ardour/ardour/track.h b/libs/ardour/ardour/track.h
index 5d87a13886..06ce398896 100644
--- a/libs/ardour/ardour/track.h
+++ b/libs/ardour/ardour/track.h
@@ -103,14 +103,14 @@ class Track : public Route
TrackMode _mode;
//private: (FIXME)
- struct FreezeRecordInsertInfo {
- FreezeRecordInsertInfo(XMLNode& st, boost::shared_ptr<Insert> ins)
- : state (st), insert (ins) {}
-
- XMLNode state;
- boost::shared_ptr<Insert> insert;
- PBD::ID id;
- UndoAction memento;
+ struct FreezeRecordProcessorInfo {
+ FreezeRecordProcessorInfo(XMLNode& st, boost::shared_ptr<Processor> proc)
+ : state (st), processor (proc) {}
+
+ XMLNode state;
+ boost::shared_ptr<Processor> processor;
+ PBD::ID id;
+ UndoAction memento;
};
struct FreezeRecord {
@@ -120,10 +120,10 @@ class Track : public Route
~FreezeRecord();
- boost::shared_ptr<Playlist> playlist;
- vector<FreezeRecordInsertInfo*> insert_info;
- bool have_mementos;
- FreezeState state;
+ boost::shared_ptr<Playlist> playlist;
+ vector<FreezeRecordProcessorInfo*> processor_info;
+ bool have_mementos;
+ FreezeState state;
};
struct RecEnableControllable : public PBD::Controllable {
@@ -135,11 +135,6 @@ class Track : public Route
Track& track;
};
- //virtual void diskstream_record_enable_changed (void *src) = 0;
- //virtual void diskstream_input_channel_changed (void *src) = 0;
-
- //virtual void input_change_handler (void *src) = 0;
-
virtual void set_state_part_two () = 0;
FreezeRecord _freeze_record;
diff --git a/libs/ardour/ardour/redirect.h b/libs/ardour/ardour/io_processor.h
index bc12bb6a8a..c6224969b9 100644
--- a/libs/ardour/ardour/redirect.h
+++ b/libs/ardour/ardour/io_processor.h
@@ -32,7 +32,7 @@
#include <pbd/undo.h>
#include <ardour/ardour.h>
-#include <ardour/insert.h>
+#include <ardour/processor.h>
#include <ardour/io.h>
#include <ardour/automation_event.h>
@@ -47,15 +47,15 @@ namespace ARDOUR {
class Session;
/** A mixer strip element (Insert) with Jack ports (IO).
*/
-class Redirect : public Insert
+class IOProcessor : public Processor
{
public:
- Redirect (Session&, const string& name, Placement,
+ IOProcessor (Session&, const string& name, Placement,
int input_min = -1, int input_max = -1, int output_min = -1, int output_max = -1);
- Redirect (const Redirect&);
- virtual ~Redirect ();
+ IOProcessor (const IOProcessor&);
+ virtual ~IOProcessor ();
virtual ChanCount output_streams() const { return _io->n_outputs(); }
virtual ChanCount input_streams () const { return _io->n_inputs(); }
@@ -70,8 +70,8 @@ class Redirect : public Insert
virtual void run (BufferSet& bufs, nframes_t start_frame, nframes_t end_frame, nframes_t nframes, nframes_t offset) = 0;
void silence (nframes_t nframes, nframes_t offset);
- sigc::signal<void,Redirect*,bool> AutomationPlaybackChanged;
- sigc::signal<void,Redirect*,uint32_t> AutomationChanged;
+ sigc::signal<void,IOProcessor*,bool> AutomationPlaybackChanged;
+ sigc::signal<void,IOProcessor*,uint32_t> AutomationChanged;
XMLNode& state (bool full_state);
int set_state (const XMLNode&);
@@ -47,15 +47,15 @@ namespace ARDOUR {
class Session;
-/** A mixer strip element (Insert) with Jack ports (IO).
+/** A mixer strip element (Processor) with Jack ports (IO).
*/
diff --git a/libs/ardour/ardour/route.h b/libs/ardour/ardour/route.h
index 4f5f863fee..008d8ffcbb 100644
--- a/libs/ardour/ardour/route.h
+++ b/libs/ardour/ardour/route.h
@@ -39,12 +39,12 @@
#include <ardour/ardour.h>
#include <ardour/io.h>
#include <ardour/session.h>
-#include <ardour/redirect.h>
+#include <ardour/io_processor.h>
#include <ardour/types.h>
namespace ARDOUR {
-class Insert;
+class Processor;
class Send;
class RouteGroup;
@@ -59,7 +59,7 @@ class Route : public IO
{
protected:
- typedef list<boost::shared_ptr<Insert> > InsertList;
+ typedef list<boost::shared_ptr<Processor> > ProcessorList;
public:
@@ -100,7 +100,7 @@ class Route : public IO
virtual bool can_record() { return false; }
virtual void set_record_enable (bool yn, void *src) {}
virtual bool record_enabled() const { return false; }
- virtual void handle_transport_stopped (bool abort, bool did_locate, bool flush_inserts);
+ virtual void handle_transport_stopped (bool abort, bool did_locate, bool flush_processors);
virtual void set_pending_declick (int);
/* end of vfunc-based API */
@@ -137,54 +137,54 @@ class Route : public IO
virtual void set_meter_point (MeterPoint, void *src);
MeterPoint meter_point() const { return _meter_point; }
- /* Inserts */
+ /* Processors */
- void flush_inserts ();
+ void flush_processors ();
- template<class T> void foreach_insert (T *obj, void (T::*func)(boost::shared_ptr<Insert>)) {
- Glib::RWLock::ReaderLock lm (insert_lock);
- for (InsertList::iterator i = _inserts.begin(); i != _inserts.end(); ++i) {
+ template<class T> void foreach_processor (T *obj, void (T::*func)(boost::shared_ptr<Processor>)) {
+ Glib::RWLock::ReaderLock lm (_processor_lock);
+ for (ProcessorList::iterator i = _processors.begin(); i != _processors.end(); ++i) {
(obj->*func) (*i);
}
}
- boost::shared_ptr<Insert> nth_insert (uint32_t n) {
- Glib::RWLock::ReaderLock lm (insert_lock);
- InsertList::iterator i;
- for (i = _inserts.begin(); i != _inserts.end() && n; ++i, --n);
- if (i == _inserts.end()) {
- return boost::shared_ptr<Redirect> ();
+ boost::shared_ptr<Processor> nth_processor (uint32_t n) {
+ Glib::RWLock::ReaderLock lm (_processor_lock);
+ ProcessorList::iterator i;
+ for (i = _processors.begin(); i != _processors.end() && n; ++i, --n);
+ if (i == _processors.end()) {
+ return boost::shared_ptr<IOProcessor> ();
} else {
return *i;
}
}
- ChanCount max_insert_outs () const { return insert_max_outs; }
+ ChanCount max_processor_outs () const { return processor_max_outs; }
ChanCount pre_fader_streams() const;
/** A record of the stream configuration at some point in the insert list.
* Used to return where and why an insert list configuration request failed.
*/
- struct InsertStreams {
- InsertStreams(size_t i=0, ChanCount c=ChanCount()) : index(i), count(c) {}
+ struct ProcessorStreams {
+ ProcessorStreams(size_t i=0, ChanCount c=ChanCount()) : index(i), count(c) {}
- size_t index; ///< Index of insert where configuration failed
- ChanCount count; ///< Input requested of insert
+ size_t index; ///< Index of processor where configuration failed
+ ChanCount count; ///< Input requested of processor
};
- int add_insert (boost::shared_ptr<Insert>, InsertStreams* err = 0);
- int add_inserts (const InsertList&, InsertStreams* err = 0);
- int remove_insert (boost::shared_ptr<Insert>, InsertStreams* err = 0);
- int copy_inserts (const Route&, Placement, InsertStreams* err = 0);
- int sort_inserts (InsertStreams* err = 0);
- void disable_inserts (Placement);
- void disable_inserts ();
+ int add_processor (boost::shared_ptr<Processor>, ProcessorStreams* err = 0);
+ int add_processors (const ProcessorList&, ProcessorStreams* err = 0);
+ int remove_processor (boost::shared_ptr<Processor>, ProcessorStreams* err = 0);
+ int copy_processors (const Route&, Placement, ProcessorStreams* err = 0);
+ int sort_processors (ProcessorStreams* err = 0);
+ void disable_processors (Placement);
+ void disable_processors ();
void disable_plugins (Placement);
void disable_plugins ();
void ab_plugins (bool forward);
- void clear_inserts (Placement);
- void all_inserts_flip();
- void all_inserts_active (Placement, bool state);
+ void clear_processors (Placement);
+ void all_processors_flip();
+ void all_processors_active (Placement, bool state);
virtual nframes_t update_total_latency();
nframes_t signal_latency() const { return _own_latency; }
@@ -198,7 +198,7 @@ class Route : public IO
sigc::signal<void,void*> post_fader_changed;
sigc::signal<void,void*> control_outs_changed;
sigc::signal<void,void*> main_outs_changed;
- sigc::signal<void> inserts_changed;
+ sigc::signal<void> processors_changed;
sigc::signal<void,void*> record_enable_changed;
sigc::signal<void,void*> edit_group_changed;
sigc::signal<void,void*> mix_group_changed;
@@ -215,8 +215,8 @@ class Route : public IO
int set_state(const XMLNode& node);
virtual XMLNode& get_template();
- XMLNode& get_insert_state ();
- int set_insert_state (const XMLNode&);
+ XMLNode& get_processor_state ();
+ int set_processor_state (const XMLNode&);
sigc::signal<void,void*> SelectedChanged;
@@ -290,29 +290,31 @@ class Route : public IO
gain_t desired_solo_gain;
gain_t desired_mute_gain;
- nframes_t check_initial_delay (nframes_t, nframes_t&, nframes_t&);
+
nframes_t _initial_delay;
nframes_t _roll_delay;
nframes_t _own_latency;
- InsertList _inserts;
- Glib::RWLock insert_lock;
- IO *_control_outs;
- Glib::Mutex control_outs_lock;
- RouteGroup *_edit_group;
- RouteGroup *_mix_group;
- std::string _comment;
- bool _have_internal_generator;
+ ProcessorList _processors;
+ Glib::RWLock _processor_lock;
+ IO *_control_outs;
+ Glib::Mutex _control_outs_lock;
+ RouteGroup *_edit_group;
+ RouteGroup *_mix_group;
+ std::string _comment;
+ bool _have_internal_generator;
ToggleControllable _solo_control;
ToggleControllable _mute_control;
+ nframes_t check_initial_delay (nframes_t, nframes_t&, nframes_t&);
+
void passthru (nframes_t start_frame, nframes_t end_frame,
nframes_t nframes, nframes_t offset, int declick, bool meter_inputs);
virtual void process_output_buffers (BufferSet& bufs,
nframes_t start_frame, nframes_t end_frame,
- nframes_t nframes, nframes_t offset, bool with_inserts, int declick,
+ nframes_t nframes, nframes_t offset, bool with_processors, int declick,
bool meter);
protected:
@@ -327,14 +329,14 @@ class Route : public IO
sigc::connection input_signal_connection;
- ChanCount insert_max_outs;
+ ChanCount processor_max_outs;
uint32_t _remote_control_id;
uint32_t pans_required() const;
ChanCount n_process_buffers ();
virtual int _set_state (const XMLNode&, bool call_base);
- virtual void _set_insert_states (const XMLNodeList&);
+ virtual void _set_processor_states (const XMLNodeList&);
private:
void init ();
@@ -355,24 +357,24 @@ class Route : public IO
void input_change_handler (IOChange, void *src);
void output_change_handler (IOChange, void *src);
- int reset_plugin_counts (InsertStreams*); /* locked */
- int _reset_plugin_counts (InsertStreams*); /* unlocked */
+ int reset_plugin_counts (ProcessorStreams*); /* locked */
+ int _reset_plugin_counts (ProcessorStreams*); /* unlocked */
- /* insert I/O channels and plugin count handling */
+ /* processor I/O channels and plugin count handling */
- struct InsertCount {
- boost::shared_ptr<ARDOUR::Insert> insert;
+ struct ProcessorCount {
+ boost::shared_ptr<ARDOUR::Processor> processor;
ChanCount in;
ChanCount out;
- InsertCount (boost::shared_ptr<ARDOUR::Insert> ins) : insert(ins) {}
+ ProcessorCount (boost::shared_ptr<ARDOUR::Processor> ins) : processor(ins) {}
};
- int32_t apply_some_plugin_counts (std::list<InsertCount>& iclist);
- bool check_some_plugin_counts (std::list<InsertCount>& iclist, ChanCount required_inputs, InsertStreams* err_streams);
+ int32_t apply_some_plugin_counts (std::list<ProcessorCount>& iclist);
+ bool check_some_plugin_counts (std::list<ProcessorCount>& iclist, ChanCount required_inputs, ProcessorStreams* err_streams);
void set_deferred_state ();
- void add_insert_from_xml (const XMLNode&);
+ void add_processor_from_xml (const XMLNode&);
};
} // namespace ARDOUR
@@ -137,54 +137,54 @@ class Route : public IO
ChanCount pre_fader_streams() const;
- /** A record of the stream configuration at some point in the insert list.
- * Used to return where and why an insert list configuration request failed.
+ /** A record of the stream configuration at some point in the processor list.
+ * Used to return where and why an processor list configuration request failed.
*/